Crate liminal_ark_pnbr_poseidon_parameters

Crate liminal_ark_pnbr_poseidon_parameters 

Structs

ArcMatrix
Represents an matrix of round constants.
InputParameters
Input parameters that are used to generate Poseidon parameters.
Matrix
Represents a matrix over PrimeField elements.
MdsMatrix
Represents an MDS (maximum distance separable) matrix.
OptimizedArcMatrix
Represents an optimized matrix of round constants.
OptimizedMdsMatrices
Represents an optimized MDS (maximum distance separable) matrix.
PoseidonParameters
A set of Poseidon parameters for a given set of input parameters.
RoundNumbers
RoundNumbers required for security based on known attacks.
SquareMatrix
Represents a square matrix over PrimeField elements

Enums

Alpha
The exponent in Sbox(x) = x^\alpha.

Traits

MatrixOperations
SquareMatrixOperations
Matrix operations that are defined on square matrices.

Functions

dot_product
Compute vector dot product
mat_mul
Multiply two matrices