Structs
- ArcMatrix
- Represents an matrix of round constants.
- Input
Parameters - Input parameters that are used to generate Poseidon parameters.
- Matrix
- Represents a matrix over
PrimeFieldelements. - MdsMatrix
- Represents an MDS (maximum distance separable) matrix.
- Optimized
ArcMatrix - Represents an optimized matrix of round constants.
- Optimized
MdsMatrices - Represents an optimized MDS (maximum distance separable) matrix.
- Poseidon
Parameters - A set of Poseidon parameters for a given set of input parameters.
- Round
Numbers RoundNumbersrequired for security based on known attacks.- Square
Matrix - Represents a square matrix over
PrimeFieldelements
Enums
- Alpha
- The exponent in
Sbox(x) = x^\alpha.
Traits
- Matrix
Operations - Square
Matrix Operations - Matrix operations that are defined on square matrices.
Functions
- dot_
product - Compute vector dot product
- mat_mul
- Multiply two matrices